<?

/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
/* (c) 2000 Oleg V. Kalashnikov <oleg@ok.gnu.zp.ua> */

include("../application.inc.php");

$stringtsf_stripped = ereg_replace ("\+", "", $stringtsf);

if (empty($stringtsf_stripped)) {
	header("Location: $CFG->firstpage");
}

if (!isset($page_number) || $dbchanged) {
//	$qid_p = find_products(&$stringtsf_stripped, $case_sensitive, $concatenation);
	find_products(&$qid_p, &$stringtsf_stripped, $case_sensitive, $concatenation);
//	$SESSION["numr"] = db_num_rows($qid_p);
	$SESSION["numr"] = $qid_p->num_rows();
	for ($i=0; $i<$SESSION["numr"]; $i++) {
//		$SESSION["searchres"][$i] = db_fetch_array($qid_p, $i);
		$qid_p->seek($i);
		$qid_p->next_record();
		$SESSION["searchres"][$i]["id"] = $qid_p->f("id");
		$SESSION["searchres"][$i]["name"] = $qid_p->f("name");
		$SESSION["searchres"][$i]["price"] = $qid_p->f("price");
		$SESSION["searchres"][$i]["description"] = $qid_p->f("description");
		$SESSION["searchres"][$i]["thumbwidth"] = $qid_p->f("thumbwidth");
		$SESSION["searchres"][$i]["thumbheight"] = $qid_p->f("thumbheight");
		$SESSION["searchres"][$i]["special_level"] = $qid_p->f("special_level");
		$SESSION["searchres"][$i]["bname"] = $qid_p->f("bname");
		$SESSION["searchres"][$i]["iva"] = $qid_p->f("iva");
		$SESSION["searchres"][$i]["discount"] = $qid_p->f("discount");
		$SESSION["searchres"][$i]["discqty"] = $qid_p->f("discqty");
		$SESSION["searchres"][$i]["weight"] = $qid_p->f("weight");
	}
	if (!isset($page_number)) {
		$page_number = 1;
	}
}

$DOC_TITLE = "Search_Results";
$SESSION["goback"]["request_uri"] = $REQUEST_URI;
$SESSION["goback"]["query_string"] = $QUERY_STRING;
include("$CFG->dirroot"."/header.php");
if ($SESSION["numr"] > $SESSION["max_results"]) {
	$t->set_file(array("page" => "templates/".$SESSION["lang"]."/too_many_results.ihtml"));
	$t->set_var("numresults", $SESSION["numr"]);
	$t->pparse("out", "page");
//	include("templates/".$SESSION["lang"]."/too_many_results.ihtml");
} else {
	if ($SESSION["numr"] > $SESSION["products_per_page"]) {
		$first = ($page_number-1)*$SESSION["products_per_page"];
		$last = $SESSION["numr"] < $page_number*$SESSION["products_per_page"] ? $SESSION["numr"]-1 : $page_number*$SESSION["products_per_page"]-1;
		$num_pages = $SESSION["numr"] / $SESSION["products_per_page"];
		if (!($num_pages == (integer) $num_pages)) {
			$num_pages = (integer) $num_pages + 1;
		}
	} else {
		$first = 0;
		$last = $SESSION["numr"] - 1;
	}
}

include("search_results.php");

include("$CFG->dirroot"."/footer.php");

?>
